@@ -1,4 +1,3 @@
-from rest_framework import serializers
 from rest_framework.decorators import action
 from rest_framework.response import Response
 from rest_framework.routers import APIRootView
@@ -6,11 +5,11 @@ from rest_framework.routers import APIRootView
 from netbox.api.viewsets import NetBoxModelViewSet
 
 from netbox_disk.api.serializers import (
-    DiskSerializer,
+    DriveSerializer,
     FilesystemSerializer,
 )
-from netbox_disk.filters import DiskFilter, FilesystemFilter
-from netbox_disk.models import Disk, Filesystem
+from netbox_disk.filters import DriveFilter, FilesystemFilter
+from netbox_disk.models import Drive, Filesystem
 
 
 class NetboxDiskRootView(APIRootView):
@@ -22,15 +21,15 @@ class NetboxDiskRootView(APIRootView):
         return "NetboxDisk"
 
 
-class DiskViewSet(NetBoxModelViewSet):
-    queryset = Disk.objects.all()
-    serializer_class = DiskSerializer
-    filterset_class = DiskFilter
+class DriveViewSet(NetBoxModelViewSet):
+    queryset = Drive.objects.all()
+    serializer_class = DriveSerializer
+    filterset_class = DriveFilter
 
     @action(detail=True, methods=["get"])
-    def disk(self, request, pk=None):
-        disks = Disk.objects.filter(disk__id=pk)
-        serializer = DiskSerializer(disks, many=True, context={"request": request})
+    def drive(self, request, pk=None):
+        drives = Drive.objects.filter(drive__id=pk)
+        serializer = DriveSerializer(drives, many=True, context={"request": request})
         return Response(serializer.data)
 
 
