@@ -1,12 +1,8 @@
-from django import forms
 
 from django.forms import (
     CharField,
-    IntegerField,
-    BooleanField,
-    NullBooleanField,
+
 )
-from django.urls import reverse_lazy
 
 from netbox.forms import (
     NetBoxModelBulkEditForm,
@@ -14,19 +10,7 @@ from netbox.forms import (
     NetBoxModelImportForm,
     NetBoxModelForm,
 )
-from utilities.forms import (
-    add_blank_choice,
-    BulkEditNullBooleanSelect,
-    DynamicModelMultipleChoiceField,
-    TagFilterField,
-    StaticSelect,
-    CSVChoiceField,
-    CSVModelChoiceField,
-    DynamicModelChoiceField,
-    APISelect,
-    StaticSelectMultiple,
-    add_blank_choice,
-)
+
 
 from netbox_disk.models import Filesystem
 
@@ -86,4 +70,4 @@ class FilesystemBulkEditForm(NetBoxModelBulkEditForm):
             ("fs", "description"),
         ),
     )
-    nullable_fields = ("description")
+    nullable_fields = ["description"]
