@@ -21,6 +21,9 @@ class Drive(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='drive',
     )
+    identifier = models.CharField(
+        max_length=255,
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -44,10 +47,11 @@ class Drive(NetBoxModel):
 
     # this is not needed if small_image is created at set_image
     def save(self, *args, **kwargs):
-        queryset = Drive.objects.all()
-        result = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").first()
+        number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
+
         logger = logging.getLogger('netbox_disk.Drive')
-        logger.warning(f"Failed login attempt for username: {result}")
+        logger.info(f"-------- Save Result: {number_of_hard_drives}")
+
         super(Drive, self).save(*args, **kwargs)
 
 
