@@ -2,9 +2,7 @@ import django_tables2 as tables
 
 from netbox.tables import (
     NetBoxTable,
-    ChoiceFieldColumn,
     ToggleColumn,
-    TagColumn,
     ActionsColumn,
 )
 
@@ -12,7 +10,7 @@ from netbox_disk.models import Filesystem
 
 
 class FilesystemBaseTable(NetBoxTable):
-    """Base class for tables displaying Disks"""
+    """Base class for tables displaying Filesystems"""
 
     fs = tables.Column(
         linkify=True,
@@ -20,7 +18,7 @@ class FilesystemBaseTable(NetBoxTable):
 
 
 class FilesystemTable(FilesystemBaseTable):
-    """Table for displaying Disk objects."""
+    """Table for displaying Filesystem objects."""
 
     pk = ToggleColumn()
 
